@@ -3,12 +3,14 @@
 # This is the primary class for the DocKnot application, which supports
 # generation of various documentation files based on package metadata and
 # general templates.
+#
+# SPDX-License-Identifier: MIT
 
 ##############################################################################
 # Modules and declarations
 ##############################################################################
 
-package App::DocKnot 1.02;
+package App::DocKnot 1.03;
 
 use 5.018;
 use autodie;
@@ -602,6 +604,9 @@ sub generate {
     eval { $vars{test}{prefix} = $self->_load_metadata('test', 'prefix') };
     eval { $vars{test}{suffix} = $self->_load_metadata('test', 'suffix') };
 
+    # Load support sections if they exist.
+    eval { $vars{support}{extra} = $self->_load_metadata('support', 'extra') };
+
     # Add code references for our defined helper functions.
     $vars{center}    = $self->_code_for_center;
     $vars{copyright} = $self->_code_for_copyright($data_ref->{copyrights});
@@ -727,7 +732,7 @@ Russ Allbery <rra@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2013, 2014, 2015, 2016, 2017 Russ Allbery <rra@cpan.org>
+Copyright 2013-2018 Russ Allbery <rra@cpan.org>
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -756,3 +761,7 @@ App::DocKnot is available from CPAN, or directly from its web site at
 L<https://www.eyrie.org/~eagle/software/docknot/>.
 
 =cut
+
+# Local Variables:
+# copyright-at-end-flag: t
+# End:
